@@ -1,21 +1,9 @@
 /*
  *  fileresourceconfigmanager.cpp  -  config manager for resources accessed via file system
  *  Program:  kalarm
- *  Copyright © 2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "fileresourceconfigmanager.h"
@@ -75,15 +63,15 @@ void FileResourceConfigManager::createResources(QObject* parent)
         std::sort(resourceGroups.begin(), resourceGroups.end(),
                   [](const QString& g1, const QString& g2)
                   {
-                      return g1.mid(9).toInt() < g2.mid(9).toInt();
+                      return g1.midRef(9).toInt() < g2.midRef(9).toInt();
                   });
 
         KConfigGroup general(manager->mConfig, GROUP_GENERAL);
         manager->mLastId = general.readEntry(KEY_LASTID, 0) | ResourceType::IdFlag;
 
-        for (const QString& resourceGroup : resourceGroups)
+        for (const QString& resourceGroup : qAsConst(resourceGroups))
         {
-            int groupIndex = resourceGroup.mid(9).toInt();
+            int groupIndex = resourceGroup.midRef(9).toInt();
             FileResourceSettings::Ptr settings(new FileResourceSettings(manager->mConfig, resourceGroup));
             if (!settings->isValid())
             {
